plugins

package
v0.0.0-...-6584cc4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 26, 2017 License: Apache-2.0 Imports: 10 Imported by: 0

Documentation

Overview

The plugins package contains metricd plugins.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Graphite

type Graphite struct {
	// A channel, which will receive metrics from the users.
	Metrics chan *pb.Metric
	// Location of the Graphite server.
	Loc string
	// contains filtered or unexported fields
}

Graphite object represents a connection to a Graphite server, located at "host:port" supplied in Loc.

func NewGraphite

func NewGraphite(metricChannel chan *pb.Metric, graphiteUrl string) *Graphite

func (*Graphite) Run

func (g *Graphite) Run()

Runs the submission of the metrics, received on Graphite.Metrics to the Grapite server, located at host:port, supplied in Graphite.Loc.

Directories

Path Synopsis
The influxdb metricd plugin.
The influxdb metricd plugin.

Jump to